﻿using System;
using System.Windows.Forms;
using GrapeCity.CalcEngine;
using GrapeCity.Spreadsheet;

namespace ExternalVariablesDemoCS
{
    // Creating and defining the external variable
    public class TextBoxExternalVariable : ExternalVariable
    {
        private TextBox _textBox;
        private bool _asInput;
        public TextBoxExternalVariable(TextBox textBox, bool asInput)
        {
            _textBox = textBox;
            if (asInput)
            {
                textBox.TextChanged += TextBox_TextChanged;
            }
        }
        private void TextBox_TextChanged(object sender, EventArgs e)
        {
            Dirty();
        }

        protected override bool OnDirtying()
        {
            return !_asInput;
        }

        protected override void OnDirtied()
        {
            Refresh();
        }

        protected override void EvaluateCore(IEvaluationContext context,
         IValue result)
        {
            string text = _textBox.Text;
            if (!string.IsNullOrEmpty(text) && double.TryParse(text,
                 out double dblValue))
            {
                result.SetValue(dblValue);
            }
            else
            {
                result.SetValue(text);
            }
        }

        public void Refresh()
        {
            if (!_asInput)
            {
                _textBox.Text = this.Value.GetText();
            }
        }
    }
}
